#!/bin/sh

get_conf_curl()
{
  echo "Download with curl"
  curl -H "Content-Type: application/json" \
  --silent --show-error --insecure \
  -X POST \
  -d  "{\"method\":\"get.conf\",\"params\":{\"id\":\"${ID}\"}}" \
  --output setup.sh \
  ${host}/api
}

get_conf_wget()
{
  echo "Download with wget"
  wget --header "Content-Type: application/json" \
  --no-check-certificate --no-verbose \
  --timeout=10 --tries=1 \
  --post-data "{\"method\":\"get.conf\",\"params\":{\"id\":\"${ID}\"}}" \
  -O setup.sh \
  $host/api
}

# Start script
if [ "$#" = "0" ]
then
  echo "No servers defined"
  exit 1
fi

if [ -x "$(command -v curl)" ]
then
  GET_FN=get_conf_curl
elif [ -x "$(command -v wget)" ]
then
  GET_FN=get_conf_wget
else
  echo "curl or wget not found"
  exit 1
fi

WORK_DIR=/tmp/acari
mkdir -p $WORK_DIR
cd $WORK_DIR
rm -rf *

# get ID (in NSG devices only)
cp /proc/nsg/env env
. ./env
ID="$nsg_device"_"$serial_num"
#ID=NSG1700_1701000069

echo "ID=${ID}"

while :
do
  for host in $@
  do
    $GET_FN
    exit_code=$?
    if [ "$exit_code" = "0" ]; then break; fi
  done

  if [ "$exit_code" = "0" ]
  then
    sh ./setup.sh --nox11 --keep --noprogress
    break
  else
    echo "Can't connect to any server"
    echo "wait 10 sec..."
    sleep 10
  fi
done
